(*---------------------------------------------------------------------------
   Copyright (c) 2018 The odig programmers. All rights reserved.
   Distributed under the ISC license, see terms at the end of the file.
  ---------------------------------------------------------------------------*)

(** mld and HTML pages generated by odig itself. *)

open Odig_support

(** {1:pages Pages} *)

val index_mld :
  Conf.t -> Pkg.t -> Pkg_info.t -> user_index:string option ->
  with_tag_links:bool -> string
(** [index_mld conf pkg pkg_info ~user_index ~with_tag_links ] is an
    [index.mld] page for package [pkg] with info [pkg_info].
    {ul
    {- If [user_index] is [Some content], that user provided content is
       integrated in the result (a leading section ["{0"] is stripped
       away though) and no module index is generated by the function.}
    {- [with_tag_links], if [true] assumes the package list generated
       by {!pkg_list} has a tag index and links the tags of the
       metadata section into it.}} *)

val pkgs_with_html_docs : Conf.t -> Pkg.t list
(** [pkg_with_html_docs c] looks up in [c] packages that
    seem to have generated documentation. *)

val pkg_list :
  Conf.t -> index_title:string option -> raw_index_intro:string option ->
  raw_index_toc:string option -> tag_index:bool ->
  ocaml_manual_uri:string option -> Pkg.t list -> string
(** [pkg_list c ~index_title ~raw_index_intro ~tag_index ~ocaml_manual_uri pkgs]
    is an HTML page package list for the packages [pkgs].
    {ul
    {- [index_title] is a title for the page with the list of
       packages; if unspecified one is automatically generated.}
    {- [raw_index_intro] is the HTML markup that is inserted before the
       list of packages; if unspecified one is automatically
       generated.}
    {- [raw_index_toc] is the HTML markup that is inserted in the toc
       list of packages page; if unspecified one is automatically
       generated.}
    {- [tag_index] if [true] a package tag is added to the page after
       the list of packages by name.}
    {- [ocaml_manual_uri] is a local URI to the OCaml manual if unspecified
       the online manual is linked.}} *)

(*---------------------------------------------------------------------------
   Copyright (c) 2018 The odig programmers

   Permission to use, copy, modify, and/or distribute this software for any
   purpose with or without fee is hereby granted, provided that the above
   copyright notice and this permission notice appear in all copies.

   THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
   WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
   MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
   ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
   WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
   ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  ---------------------------------------------------------------------------*)
